@@ -31,12 +31,12 @@ if [ "x${TRAVIS:-0}" != "x" ]; then
 fi
 
 # Otherwise, put a minimal installation inside of the cache.
-if [ "$PHP_CUSTOM_NORMAL_VERSION" == "8.2.0" ] ; then
-	PHP_CUSTOM_VERSION=8.2.0RC4
+if [ "$PHP_CUSTOM_NORMAL_VERSION" == "8.3.0" ] ; then
+	PHP_CUSTOM_VERSION=8.3.0beta1
 	PHP_FOLDER="php-$PHP_CUSTOM_VERSION"
 
 	PHP_TAR_FILE="$PHP_FOLDER.tar.bz2"
-	PHP_TAR_URL=https://downloads.php.net/~sergey/$PHP_TAR_FILE
+	PHP_TAR_URL=https://downloads.php.net/~eric/$PHP_TAR_FILE
 else
 	PHP_FOLDER="php-$PHP_CUSTOM_VERSION"
 
